@@ -3,14 +3,15 @@
 extern crate oxipng;
 extern crate test;
 
-use oxipng::{internal_tests::*, Interlacing};
+use oxipng::internal_tests::*;
+use oxipng::*;
 use std::path::PathBuf;
 use test::Bencher;
 
 #[bench]
 fn interlacing_16_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from("tests/files/rgb_16_should_be_rgb_16.png"));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::Adam7));
 }
@@ -18,7 +19,7 @@ fn interlacing_16_bits(b: &mut Bencher) {
 #[bench]
 fn interlacing_8_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from("tests/files/rgb_8_should_be_rgb_8.png"));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::Adam7));
 }
@@ -28,7 +29,7 @@ fn interlacing_4_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/palette_4_should_be_palette_4.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::Adam7));
 }
@@ -38,7 +39,7 @@ fn interlacing_2_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/palette_2_should_be_palette_2.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::Adam7));
 }
@@ -48,7 +49,7 @@ fn interlacing_1_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/palette_1_should_be_palette_1.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::Adam7));
 }
@@ -58,7 +59,7 @@ fn deinterlacing_16_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/interlaced_rgb_16_should_be_rgb_16.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::None));
 }
@@ -68,7 +69,7 @@ fn deinterlacing_8_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/interlaced_rgb_8_should_be_rgb_8.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::None));
 }
@@ -78,7 +79,7 @@ fn deinterlacing_4_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/interlaced_palette_4_should_be_palette_4.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::None));
 }
@@ -88,7 +89,7 @@ fn deinterlacing_2_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/interlaced_palette_2_should_be_palette_2.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::None));
 }
@@ -98,7 +99,7 @@ fn deinterlacing_1_bits(b: &mut Bencher) {
     let input = test::black_box(PathBuf::from(
         "tests/files/interlaced_palette_1_should_be_palette_1.png",
     ));
-    let png = PngData::new(&input, false).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
     b.iter(|| png.raw.change_interlacing(Interlacing::None));
 }
