@@ -1,14 +1,14 @@
-use crate::colors::ColorType;
+use crate::colors::{BitDepth, ColorType};
 use crate::deflate;
 use crate::error::PngError;
 use crate::filters::*;
 use crate::headers::*;
 use crate::interlace::{deinterlace_image, interlace_image, Interlacing};
+use crate::Options;
 use bitvec::bitarr;
-use indexmap::IndexMap;
 use libdeflater::{CompressionLvl, Compressor};
+use log::warn;
 use rgb::ComponentSlice;
-use rgb::RGBA8;
 use rustc_hash::FxHashMap;
 use std::fs::File;
 use std::io::{BufReader, Read, Write};
@@ -31,13 +31,6 @@ pub struct PngImage {
     pub ihdr: IhdrData,
     /// The uncompressed, unfiltered data from the IDAT chunk
     pub data: Vec<u8>,
-    /// The palette containing colors used in an Indexed image
-    /// Contains 3 bytes per color (R+G+B), up to 768
-    pub palette: Option<Vec<RGBA8>>,
-    /// The pixel value that should be rendered as transparent
-    pub transparency_pixel: Option<Vec<u8>>,
-    /// All non-critical headers from the PNG are stored here
-    pub aux_headers: IndexMap<[u8; 4], Vec<u8>>,
 }
 
 /// Contains all data relevant to a PNG image
@@ -47,19 +40,17 @@ pub struct PngData {
     pub raw: Arc<PngImage>,
     /// The filtered and compressed data of the IDAT chunk
     pub idat_data: Vec<u8>,
-    /// The filtered, uncompressed data of the IDAT chunk
-    pub filtered: Vec<u8>,
+    /// All non-critical chunks from the PNG are stored here
+    pub aux_chunks: Vec<Chunk>,
 }
 
-type PaletteWithTrns = (Option<Vec<RGBA8>>, Option<Vec<u8>>);
-
 impl PngData {
     /// Create a new `PngData` struct by opening a file
     #[inline]
-    pub fn new(filepath: &Path, fix_errors: bool) -> Result<Self, PngError> {
+    pub fn new(filepath: &Path, opts: &Options) -> Result<Self, PngError> {
         let byte_data = Self::read_file(filepath)?;
 
-        Self::from_slice(&byte_data, fix_errors)
+        Self::from_slice(&byte_data, opts)
     }
 
     pub fn read_file(filepath: &Path) -> Result<Vec<u8>, PngError> {
@@ -88,7 +79,7 @@ impl PngData {
     }
 
     /// Create a new `PngData` struct by reading a slice
-    pub fn from_slice(byte_data: &[u8], fix_errors: bool) -> Result<Self, PngError> {
+    pub fn from_slice(byte_data: &[u8], opts: &Options) -> Result<Self, PngError> {
         let mut byte_offset: usize = 0;
         // Test that png header is valid
         let header = byte_data.get(0..8).ok_or(PngError::TruncatedData)?;
@@ -96,79 +87,77 @@ impl PngData {
             return Err(PngError::NotPNG);
         }
         byte_offset += 8;
-        // Read the data headers
-        let mut aux_headers: IndexMap<[u8; 4], Vec<u8>> = IndexMap::new();
-        let mut idat_headers: Vec<u8> = Vec::new();
-        while let Some(header) = parse_next_header(byte_data, &mut byte_offset, fix_errors)? {
-            match &header.name {
-                b"IDAT" => idat_headers.extend_from_slice(header.data),
-                b"acTL" => return Err(PngError::APNGNotSupported),
+
+        // Read the data chunks
+        let mut idat_data: Vec<u8> = Vec::new();
+        let mut key_chunks: FxHashMap<[u8; 4], Vec<u8>> = FxHashMap::default();
+        let mut aux_chunks: Vec<Chunk> = Vec::new();
+        while let Some(chunk) = parse_next_chunk(byte_data, &mut byte_offset, opts.fix_errors)? {
+            match &chunk.name {
+                b"IDAT" => {
+                    if idat_data.is_empty() {
+                        // Keep track of where the first IDAT sits relative to other chunks
+                        aux_chunks.push(Chunk {
+                            name: chunk.name,
+                            data: Vec::new(),
+                        })
+                    }
+                    idat_data.extend_from_slice(chunk.data);
+                }
+                b"IHDR" | b"PLTE" | b"tRNS" => {
+                    key_chunks.insert(chunk.name, chunk.data.to_owned());
+                }
                 _ => {
-                    aux_headers.insert(header.name, header.data.to_owned());
+                    if opts.strip.keep(&chunk.name) {
+                        aux_chunks.push(Chunk {
+                            name: chunk.name,
+                            data: chunk.data.to_owned(),
+                        })
+                    } else if chunk.name == *b"acTL" {
+                        warn!(
+                            "Stripping animation data from APNG - image will become standard PNG"
+                        );
+                    }
                 }
             }
         }
-        // Parse the headers into our PngData
-        if idat_headers.is_empty() {
+
+        // Parse the chunks into our PngData
+        if idat_data.is_empty() {
             return Err(PngError::ChunkMissing("IDAT"));
         }
-        let ihdr = match aux_headers.remove(b"IHDR") {
+        let ihdr_chunk = match key_chunks.remove(b"IHDR") {
             Some(ihdr) => ihdr,
             None => return Err(PngError::ChunkMissing("IHDR")),
         };
-        let ihdr_header = parse_ihdr_header(&ihdr)?;
-        let raw_data = deflate::inflate(idat_headers.as_ref(), ihdr_header.raw_data_size())?;
+        let ihdr = parse_ihdr_chunk(
+            &ihdr_chunk,
+            key_chunks.remove(b"PLTE"),
+            key_chunks.remove(b"tRNS"),
+        )?;
+        let raw_data = deflate::inflate(idat_data.as_ref(), ihdr.raw_data_size())?;
 
         // Reject files with incorrect width/height or truncated data
-        if raw_data.len() != ihdr_header.raw_data_size() {
+        if raw_data.len() != ihdr.raw_data_size() {
             return Err(PngError::TruncatedData);
         }
 
-        let (palette, transparency_pixel) = Self::palette_to_rgba(
-            ihdr_header.color_type,
-            aux_headers.remove(b"PLTE"),
-            aux_headers.remove(b"tRNS"),
-        )?;
-
         let mut raw = PngImage {
-            ihdr: ihdr_header,
+            ihdr,
             data: raw_data,
-            palette,
-            transparency_pixel,
-            aux_headers,
         };
-        let unfiltered = raw.unfilter_image()?;
+        raw.data = raw.unfilter_image()?;
         // Return the PngData
         Ok(Self {
-            idat_data: idat_headers,
-            filtered: std::mem::replace(&mut raw.data, unfiltered),
+            idat_data,
             raw: Arc::new(raw),
+            aux_chunks,
         })
     }
 
-    /// Handle transparency header
-    fn palette_to_rgba(
-        color_type: ColorType,
-        palette_data: Option<Vec<u8>>,
-        trns_data: Option<Vec<u8>>,
-    ) -> Result<PaletteWithTrns, PngError> {
-        if color_type == ColorType::Indexed {
-            let palette_data =
-                palette_data.ok_or_else(|| PngError::new("no palette in indexed image"))?;
-            let mut palette: Vec<_> = palette_data
-                .chunks(3)
-                .map(|color| RGBA8::new(color[0], color[1], color[2], 255))
-                .collect();
-
-            if let Some(trns_data) = trns_data {
-                for (color, trns) in palette.iter_mut().zip(trns_data) {
-                    color.a = trns;
-                }
-            }
-            Ok((Some(palette), None))
-        } else {
-            Ok((None, trns_data))
-        }
+    /// Return an estimate of the output size which can help with evaluation of very small data
+    pub fn estimated_output_size(&self) -> usize {
+        self.idat_data.len() + self.raw.key_chunks_size()
     }
 
     /// Format the `PngData` struct into a valid PNG bytestream
@@ -181,7 +170,7 @@ impl PngData {
         ihdr_data
             .write_all(&self.raw.ihdr.height.to_be_bytes())
             .ok();
-        ihdr_data.write_all(&[self.raw.ihdr.bit_depth.as_u8()]).ok();
+        ihdr_data.write_all(&[self.raw.ihdr.bit_depth as u8]).ok();
         ihdr_data
             .write_all(&[self.raw.ihdr.color_type.png_header_code()])
             .ok();
@@ -189,61 +178,58 @@ impl PngData {
         ihdr_data.write_all(&[0]).ok(); // Filter method -- 5-way adaptive filtering
         ihdr_data.write_all(&[self.raw.ihdr.interlaced as u8]).ok();
         write_png_block(b"IHDR", &ihdr_data, &mut output);
-        // Ancillary headers
-        for (key, header) in self
-            .raw
-            .aux_headers
+        // Ancillary chunks - split into those that come before IDAT and those that come after
+        let mut aux_split = self.aux_chunks.split(|c| &c.name == b"IDAT");
+        let aux_pre = aux_split.next().unwrap();
+        for chunk in aux_pre
             .iter()
-            .filter(|&(key, _)| !(key == b"bKGD" || key == b"hIST" || key == b"tRNS"))
+            .filter(|c| !(&c.name == b"bKGD" || &c.name == b"hIST" || &c.name == b"tRNS"))
         {
-            write_png_block(key, header, &mut output);
+            write_png_block(&chunk.name, &chunk.data, &mut output);
         }
-        // Palette
-        if let Some(ref palette) = self.raw.palette {
-            let mut palette_data = Vec::with_capacity(palette.len() * 3);
-            let mut max_palette_size = 1 << (self.raw.ihdr.bit_depth.as_u8() as usize);
-            // Ensure bKGD color doesn't get truncated from palette
-            if let Some(&idx) = self.raw.aux_headers.get(b"bKGD").and_then(|b| b.first()) {
-                max_palette_size = max_palette_size.max(idx as usize + 1);
+        // Palette and transparency
+        match &self.raw.ihdr.color_type {
+            ColorType::Indexed { palette } => {
+                let mut palette_data = Vec::with_capacity(palette.len() * 3);
+                for px in palette {
+                    palette_data.extend_from_slice(px.rgb().as_slice());
+                }
+                write_png_block(b"PLTE", &palette_data, &mut output);
+                if let Some(last_trns) = palette.iter().rposition(|px| px.a != 255) {
+                    let trns_data: Vec<_> = palette[0..=last_trns].iter().map(|px| px.a).collect();
+                    write_png_block(b"tRNS", &trns_data, &mut output);
+                }
             }
-            for px in palette.iter().take(max_palette_size) {
-                palette_data.extend_from_slice(px.rgb().as_slice());
+            ColorType::Grayscale {
+                transparent_shade: Some(trns),
+            } => {
+                // Transparency pixel - 2 byte u16
+                write_png_block(b"tRNS", &trns.to_be_bytes(), &mut output);
             }
-            write_png_block(b"PLTE", &palette_data, &mut output);
-            let num_transparent =
-                palette
-                    .iter()
-                    .take(max_palette_size)
-                    .enumerate()
-                    .fold(
-                        0,
-                        |prev, (index, px)| {
-                            if px.a == 255 {
-                                prev
-                            } else {
-                                index + 1
-                            }
-                        },
-                    );
-            if num_transparent > 0 {
-                let trns_data: Vec<_> = palette[0..num_transparent].iter().map(|px| px.a).collect();
+            ColorType::RGB {
+                transparent_color: Some(trns),
+            } => {
+                // Transparency pixel - 6 byte RGB16
+                let trns_data: Vec<_> = trns.iter().flat_map(|c| c.to_be_bytes()).collect();
                 write_png_block(b"tRNS", &trns_data, &mut output);
             }
-        } else if let Some(ref transparency_pixel) = self.raw.transparency_pixel {
-            // Transparency pixel
-            write_png_block(b"tRNS", transparency_pixel, &mut output);
+            _ => {}
         }
-        // Special ancillary headers that need to come after PLTE but before IDAT
-        for (key, header) in self
-            .raw
-            .aux_headers
+        // Special ancillary chunks that need to come after PLTE but before IDAT
+        for chunk in aux_pre
             .iter()
-            .filter(|&(key, _)| key == b"bKGD" || key == b"hIST" || key == b"tRNS")
+            .filter(|c| &c.name == b"bKGD" || &c.name == b"hIST" || &c.name == b"tRNS")
         {
-            write_png_block(key, header, &mut output);
+            write_png_block(&chunk.name, &chunk.data, &mut output);
         }
         // IDAT data
         write_png_block(b"IDAT", &self.idat_data, &mut output);
+        // Ancillary chunks that come after IDAT
+        for aux_post in aux_split {
+            for chunk in aux_post {
+                write_png_block(&chunk.name, &chunk.data, &mut output);
+            }
+        }
         // Stream end
         write_png_block(b"IEND", &[], &mut output);
 
@@ -274,8 +260,35 @@ impl PngImage {
 
     /// Return the number of channels in the image, based on color type
     #[inline]
-    pub fn channels_per_pixel(&self) -> u8 {
-        self.ihdr.color_type.channels_per_pixel()
+    pub fn channels_per_pixel(&self) -> usize {
+        self.ihdr.color_type.channels_per_pixel() as usize
+    }
+
+    /// Return the number of bytes per channel in the image
+    #[inline]
+    pub fn bytes_per_channel(&self) -> usize {
+        match self.ihdr.bit_depth {
+            BitDepth::Sixteen => 2,
+            // Depths lower than 8 will round up to 1 byte
+            _ => 1,
+        }
+    }
+
+    /// Calculate the size of the PLTE and tRNS chunks
+    pub fn key_chunks_size(&self) -> usize {
+        match &self.ihdr.color_type {
+            ColorType::Indexed { palette } => {
+                let plte = 12 + palette.len() * 3;
+                if let Some(trns) = palette.iter().rposition(|p| p.a != 255) {
+                    plte + 12 + trns + 1
+                } else {
+                    plte
+                }
+            }
+            ColorType::Grayscale { transparent_shade } if transparent_shade.is_some() => 12 + 2,
+            ColorType::RGB { transparent_color } if transparent_color.is_some() => 12 + 6,
+            _ => 0,
+        }
     }
 
     /// Return an iterator over the scanlines of the image
@@ -287,7 +300,7 @@ impl PngImage {
     /// Reverse all filters applied on the image, returning an unfiltered IDAT bytestream
     fn unfilter_image(&self) -> Result<Vec<u8>, PngError> {
         let mut unfiltered = Vec::with_capacity(self.data.len());
-        let bpp = ((self.ihdr.bit_depth.as_u8() * self.channels_per_pixel() + 7) / 8) as usize;
+        let bpp = self.bytes_per_channel() * self.channels_per_pixel();
         let mut last_line: Vec<u8> = Vec::new();
         let mut last_pass = None;
         let mut unfiltered_buf = Vec::new();
@@ -309,13 +322,12 @@ impl PngImage {
     /// Apply the specified filter type to all rows in the image
     pub fn filter_image(&self, filter: RowFilter, optimize_alpha: bool) -> Vec<u8> {
         let mut filtered = Vec::with_capacity(self.data.len());
-        let bpp = ((self.ihdr.bit_depth.as_u8() * self.channels_per_pixel() + 7) / 8) as usize;
+        let bpp = self.bytes_per_channel() * self.channels_per_pixel();
         // If alpha optimization is enabled, determine how many bytes of alpha there are per pixel
-        let alpha_bytes = match self.ihdr.color_type {
-            ColorType::RGBA | ColorType::GrayscaleAlpha if optimize_alpha => {
-                (self.ihdr.bit_depth.as_u8() / 8) as usize
-            }
-            _ => 0,
+        let alpha_bytes = if optimize_alpha && self.ihdr.color_type.has_alpha() {
+            self.bytes_per_channel()
+        } else {
+            0
         };
 
         let mut prev_line = Vec::new();
@@ -465,14 +477,15 @@ impl PngImage {
         filtered
     }
 }
-fn write_png_block(key: &[u8], header: &[u8], output: &mut Vec<u8>) {
-    let mut header_data = Vec::with_capacity(header.len() + 4);
-    header_data.extend_from_slice(key);
-    header_data.extend_from_slice(header);
-    output.reserve(header_data.len() + 8);
-    output.extend_from_slice(&(header_data.len() as u32 - 4).to_be_bytes());
-    let crc = deflate::crc32(&header_data);
-    output.append(&mut header_data);
+
+fn write_png_block(key: &[u8], chunk: &[u8], output: &mut Vec<u8>) {
+    let mut chunk_data = Vec::with_capacity(chunk.len() + 4);
+    chunk_data.extend_from_slice(key);
+    chunk_data.extend_from_slice(chunk);
+    output.reserve(chunk_data.len() + 8);
+    output.extend_from_slice(&(chunk_data.len() as u32 - 4).to_be_bytes());
+    let crc = deflate::crc32(&chunk_data);
+    output.append(&mut chunk_data);
     output.extend_from_slice(&crc.to_be_bytes());
 }
 
