@@ -25,7 +25,7 @@ impl<'a> Iterator for ScanLines<'a> {
     type Item = ScanLine<'a>;
     #[inline]
     fn next(&mut self) -> Option<Self::Item> {
-        self.iter.next().map(|(len, pass)| {
+        self.iter.next().map(|(len, pass, num_pixels)| {
             let (data, rest) = self.raw_data.split_at(len);
             self.raw_data = rest;
             let (&filter, data) = if self.has_filter {
@@ -33,7 +33,12 @@ impl<'a> Iterator for ScanLines<'a> {
             } else {
                 (&0, data)
             };
-            ScanLine { filter, data, pass }
+            ScanLine {
+                filter,
+                data,
+                pass,
+                num_pixels,
+            }
         })
     }
 }
@@ -43,7 +48,7 @@ impl<'a> Iterator for ScanLines<'a> {
 struct ScanLineRanges {
     /// Current pass number, and 0-indexed row within the pass
     pass: Option<(u8, u32)>,
-    bits_per_pixel: u8,
+    bits_per_pixel: usize,
     width: u32,
     height: u32,
     left: usize,
@@ -53,7 +58,7 @@ struct ScanLineRanges {
 impl ScanLineRanges {
     pub fn new(png: &PngImage, has_filter: bool) -> Self {
         Self {
-            bits_per_pixel: png.ihdr.bit_depth.as_u8() * png.channels_per_pixel(),
+            bits_per_pixel: png.ihdr.bpp(),
             width: png.ihdr.width,
             height: png.ihdr.height,
             left: png.data.len(),
@@ -68,7 +73,7 @@ impl ScanLineRanges {
 }
 
 impl Iterator for ScanLineRanges {
-    type Item = (usize, Option<u8>);
+    type Item = (usize, Option<u8>, usize);
     fn next(&mut self) -> Option<Self::Item> {
         if self.left == 0 {
             return None;
@@ -143,13 +148,13 @@ impl Iterator for ScanLineRanges {
             // Standard, non-interlaced PNG scanlines
             (self.width, None)
         };
-        let bits_per_line = pixels_per_line * u32::from(self.bits_per_pixel);
-        let mut len = ((bits_per_line + 7) / 8) as usize;
+        let bits_per_line = pixels_per_line as usize * self.bits_per_pixel;
+        let mut len = (bits_per_line + 7) / 8;
         if self.has_filter {
             len += 1;
         }
         self.left = self.left.checked_sub(len)?;
-        Some((len, current_pass))
+        Some((len, current_pass, pixels_per_line as usize))
     }
 }
 
@@ -162,4 +167,6 @@ pub struct ScanLine<'a> {
     pub data: &'a [u8],
     /// The current pass if the image is interlaced
     pub pass: Option<u8>,
+    /// The number of pixels in the current scan line
+    pub num_pixels: usize,
 }
