@@ -1,62 +1,67 @@
-use indexmap::IndexSet;
-use oxipng::{internal_tests::*, Interlacing, RowFilter};
-use oxipng::{InFile, OutFile};
+use indexmap::{indexset, IndexSet};
+use oxipng::internal_tests::*;
+use oxipng::*;
 #[cfg(feature = "filetime")]
 use std::cell::RefCell;
 use std::fs::remove_file;
+#[cfg(feature = "zopfli")]
 use std::num::NonZeroU8;
 #[cfg(feature = "filetime")]
 use std::ops::Deref;
 use std::path::Path;
 use std::path::PathBuf;
 
+const GRAYSCALE: u8 = 0;
+const RGB: u8 = 2;
+const INDEXED: u8 = 3;
+const RGBA: u8 = 6;
+
 fn get_opts(input: &Path) -> (OutFile, oxipng::Options) {
     let mut options = oxipng::Options {
         force: true,
+        fast_evaluation: false,
         ..Default::default()
     };
     let mut filter = IndexSet::new();
     filter.insert(RowFilter::None);
     options.filter = filter;
 
-    (
-        OutFile::Path(Some(input.with_extension("out.png"))),
-        options,
-    )
+    (OutFile::from_path(input.with_extension("out.png")), options)
 }
 
 /// Add callback to allow checks before the output file is deleted again
+#[allow(clippy::too_many_arguments)]
 fn test_it_converts_callbacks<CBPRE, CBPOST>(
     input: PathBuf,
     output: &OutFile,
     opts: &oxipng::Options,
-    color_type_in: ColorType,
+    color_type_in: u8,
     bit_depth_in: BitDepth,
-    color_type_out: ColorType,
+    color_type_out: u8,
     bit_depth_out: BitDepth,
     mut callback_pre: CBPRE,
     mut callback_post: CBPOST,
 ) where
-    CBPOST: FnMut(&Path) -> (),
-    CBPRE: FnMut(&Path) -> (),
+    CBPOST: FnMut(&Path),
+    CBPRE: FnMut(&Path),
 {
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, opts).unwrap();
 
-    assert_eq!(png.raw.ihdr.color_type, color_type_in);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), color_type_in);
     assert_eq!(png.raw.ihdr.bit_depth, bit_depth_in);
 
     callback_pre(&input);
 
-    match oxipng::optimize(&InFile::Path(input), &output, &opts) {
+    match oxipng::optimize(&InFile::Path(input), output, opts) {
         Ok(_) => (),
         Err(x) => panic!("{}", x),
     };
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    callback_post(&output);
+    callback_post(output);
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -64,7 +69,7 @@ fn test_it_converts_callbacks<CBPRE, CBPOST>(
         }
     };
 
-    assert_eq!(png.raw.ihdr.color_type, color_type_out);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), color_type_out);
     assert_eq!(png.raw.ihdr.bit_depth, bit_depth_out);
 
     remove_file(output).ok();
@@ -75,9 +80,9 @@ fn test_it_converts(
     input: PathBuf,
     output: &OutFile,
     opts: &oxipng::Options,
-    color_type_in: ColorType,
+    color_type_in: u8,
     bit_depth_in: BitDepth,
-    color_type_out: ColorType,
+    color_type_out: u8,
     bit_depth_out: BitDepth,
 ) {
     test_it_converts_callbacks(
@@ -95,9 +100,12 @@ fn test_it_converts(
 
 #[test]
 fn verbose_mode() {
+    #[cfg(feature = "parallel")]
     use crossbeam_channel::{unbounded, Sender};
     use log::{set_logger, set_max_level, Level, LevelFilter, Log, Metadata, Record};
     use std::cell::RefCell;
+    #[cfg(not(feature = "parallel"))]
+    use std::sync::mpsc::{channel as unbounded, Sender};
 
     // Rust runs tests in parallel by default.
     // We want to make sure that we verify only logs from our test.
@@ -148,9 +156,9 @@ fn verbose_mode() {
             input,
             &output,
             &opts,
-            ColorType::RGB,
+            RGB,
             BitDepth::Eight,
-            ColorType::RGB,
+            RGB,
             BitDepth::Eight,
         );
     };
@@ -169,13 +177,23 @@ fn verbose_mode() {
         thread_exec();
     });
 
-    let mut logs: Vec<_> = receiver.into_iter().collect();
-    assert_eq!(logs.len(), 1);
-    logs.sort();
+    let logs: Vec<_> = receiver.into_iter().collect();
+    let expected_prefixes = [
+        "    500x400 pixels, PNG format",
+        "    8-bit RGB, non-interlaced",
+        "    IDAT size = 113794 bytes",
+        "    File size = 114708 bytes",
+        "Trying: 1 filters",
+        "Found better combination:",
+        "    zc = 11  f = None ",
+        "    IDAT size = ",
+        "    file size = ",
+    ];
+    assert_eq!(logs.len(), expected_prefixes.len());
     for (i, log) in logs.into_iter().enumerate() {
-        let expected_prefix = format!("    zc = 11  f = None ");
+        let expected_prefix = expected_prefixes[i];
         assert!(
-            log.starts_with(&expected_prefix),
+            log.starts_with(expected_prefix),
             "logs[{}] = {:?} doesn't start with {:?}",
             i,
             log,
@@ -184,17 +202,24 @@ fn verbose_mode() {
     }
 }
 
+fn count_chunk(png: &PngData, name: &[u8; 4]) -> usize {
+    png.aux_chunks
+        .iter()
+        .filter(|chunk| &chunk.name == name)
+        .count()
+}
+
 #[test]
 fn strip_headers_list() {
     let input = PathBuf::from("tests/files/strip_headers_list.png");
     let (output, mut opts) = get_opts(&input);
-    opts.strip = Headers::Strip(vec!["iCCP".to_owned(), "tEXt".to_owned()]);
+    opts.strip = StripChunks::Strip(indexset![*b"iCCP", *b"tEXt"]);
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
-    assert!(png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iCCP"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 3);
+    assert_eq!(count_chunk(&png, b"iTXt"), 1);
+    assert_eq!(count_chunk(&png, b"iCCP"), 1);
 
     match oxipng::optimize(&InFile::Path(input), &output, &opts) {
         Ok(_) => (),
@@ -203,7 +228,7 @@ fn strip_headers_list() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -211,9 +236,9 @@ fn strip_headers_list() {
         }
     };
 
-    assert!(!png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(!png.raw.aux_headers.contains_key(b"iCCP"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 0);
+    assert_eq!(count_chunk(&png, b"iTXt"), 1);
+    assert_eq!(count_chunk(&png, b"iCCP"), 0);
 
     remove_file(output).ok();
 }
@@ -222,13 +247,13 @@ fn strip_headers_list() {
 fn strip_headers_safe() {
     let input = PathBuf::from("tests/files/strip_headers_safe.png");
     let (output, mut opts) = get_opts(&input);
-    opts.strip = Headers::Safe;
+    opts.strip = StripChunks::Safe;
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
-    assert!(png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iCCP"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 3);
+    assert_eq!(count_chunk(&png, b"iTXt"), 1);
+    assert_eq!(count_chunk(&png, b"iCCP"), 1);
 
     match oxipng::optimize(&InFile::Path(input), &output, &opts) {
         Ok(_) => (),
@@ -237,7 +262,7 @@ fn strip_headers_safe() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -245,9 +270,9 @@ fn strip_headers_safe() {
         }
     };
 
-    assert!(!png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(!png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(png.raw.aux_headers.contains_key(b"sRGB"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 0);
+    assert_eq!(count_chunk(&png, b"iTXt"), 0);
+    assert_eq!(count_chunk(&png, b"sRGB"), 1);
 
     remove_file(output).ok();
 }
@@ -256,13 +281,13 @@ fn strip_headers_safe() {
 fn strip_headers_all() {
     let input = PathBuf::from("tests/files/strip_headers_all.png");
     let (output, mut opts) = get_opts(&input);
-    opts.strip = Headers::All;
+    opts.strip = StripChunks::All;
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
-    assert!(png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iCCP"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 3);
+    assert_eq!(count_chunk(&png, b"iTXt"), 1);
+    assert_eq!(count_chunk(&png, b"iCCP"), 1);
 
     match oxipng::optimize(&InFile::Path(input), &output, &opts) {
         Ok(_) => (),
@@ -271,7 +296,7 @@ fn strip_headers_all() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -279,9 +304,9 @@ fn strip_headers_all() {
         }
     };
 
-    assert!(!png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(!png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(!png.raw.aux_headers.contains_key(b"iCCP"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 0);
+    assert_eq!(count_chunk(&png, b"iTXt"), 0);
+    assert_eq!(count_chunk(&png, b"iCCP"), 0);
 
     remove_file(output).ok();
 }
@@ -290,13 +315,13 @@ fn strip_headers_all() {
 fn strip_headers_none() {
     let input = PathBuf::from("tests/files/strip_headers_none.png");
     let (output, mut opts) = get_opts(&input);
-    opts.strip = Headers::None;
+    opts.strip = StripChunks::None;
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &Options::default()).unwrap();
 
-    assert!(png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iCCP"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 3);
+    assert_eq!(count_chunk(&png, b"iTXt"), 1);
+    assert_eq!(count_chunk(&png, b"iCCP"), 1);
 
     match oxipng::optimize(&InFile::Path(input), &output, &opts) {
         Ok(_) => (),
@@ -305,7 +330,7 @@ fn strip_headers_none() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -313,9 +338,9 @@ fn strip_headers_none() {
         }
     };
 
-    assert!(png.raw.aux_headers.contains_key(b"tEXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iTXt"));
-    assert!(png.raw.aux_headers.contains_key(b"iCCP"));
+    assert_eq!(count_chunk(&png, b"tEXt"), 3);
+    assert_eq!(count_chunk(&png, b"iTXt"), 1);
+    assert_eq!(count_chunk(&png, b"iCCP"), 1);
 
     remove_file(output).ok();
 }
@@ -326,7 +351,7 @@ fn interlacing_0_to_1() {
     let (output, mut opts) = get_opts(&input);
     opts.interlace = Some(Interlacing::Adam7);
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &opts).unwrap();
 
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::None);
 
@@ -337,7 +362,7 @@ fn interlacing_0_to_1() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -356,7 +381,7 @@ fn interlacing_1_to_0() {
     let (output, mut opts) = get_opts(&input);
     opts.interlace = Some(Interlacing::None);
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &opts).unwrap();
 
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::Adam7);
 
@@ -367,7 +392,7 @@ fn interlacing_1_to_0() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -386,10 +411,10 @@ fn interlacing_0_to_1_small_files() {
     let (output, mut opts) = get_opts(&input);
     opts.interlace = Some(Interlacing::Adam7);
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &opts).unwrap();
 
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::None);
-    assert_eq!(png.raw.ihdr.color_type, ColorType::Indexed);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), INDEXED);
     assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
     match oxipng::optimize(&InFile::Path(input), &output, &opts) {
@@ -399,7 +424,7 @@ fn interlacing_0_to_1_small_files() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -408,8 +433,8 @@ fn interlacing_0_to_1_small_files() {
     };
 
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::Adam7);
-    assert_eq!(png.raw.ihdr.color_type, ColorType::Indexed);
-    assert_eq!(png.raw.ihdr.bit_depth, BitDepth::One);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), RGB);
+    assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
     remove_file(output).ok();
 }
@@ -420,10 +445,10 @@ fn interlacing_1_to_0_small_files() {
     let (output, mut opts) = get_opts(&input);
     opts.interlace = Some(Interlacing::None);
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &opts).unwrap();
 
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::Adam7);
-    assert_eq!(png.raw.ihdr.color_type, ColorType::Indexed);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), INDEXED);
     assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
     match oxipng::optimize(&InFile::Path(input), &output, &opts) {
@@ -433,7 +458,7 @@ fn interlacing_1_to_0_small_files() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -442,8 +467,8 @@ fn interlacing_1_to_0_small_files() {
     };
 
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::None);
-    assert_eq!(png.raw.ihdr.color_type, ColorType::Indexed);
-    // the depth can't be asserted reliably, because on such small file different zlib implementations pick different depth as the best
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), RGB);
+    assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
     remove_file(output).ok();
 }
@@ -457,7 +482,7 @@ fn interlaced_0_to_1_other_filter_mode() {
     filter.insert(RowFilter::Paeth);
     opts.filter = filter;
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &opts).unwrap();
 
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::None);
 
@@ -468,7 +493,7 @@ fn interlaced_0_to_1_other_filter_mode() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -490,8 +515,10 @@ fn preserve_attrs() {
     #[cfg(feature = "filetime")]
     let mtime_canon = RefCell::new(filetime::FileTime::from_unix_time(0, 0));
 
-    let (output, mut opts) = get_opts(&input);
-    opts.preserve_attrs = true;
+    let (mut output, opts) = get_opts(&input);
+    if let OutFile::Path { preserve_attrs, .. } = &mut output {
+        *preserve_attrs = true;
+    }
 
     #[cfg(feature = "filetime")]
     let callback_pre = |path_in: &Path| {
@@ -534,9 +561,9 @@ fn preserve_attrs() {
         input,
         &output,
         &opts,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
         callback_pre,
         callback_post,
@@ -551,9 +578,9 @@ fn fix_errors() {
     let (output, mut opts) = get_opts(&input);
     opts.fix_errors = true;
 
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &opts).unwrap();
 
-    assert_eq!(png.raw.ihdr.color_type, ColorType::RGBA);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), RGBA);
     assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
     match oxipng::optimize(&InFile::Path(input), &output, &opts) {
@@ -563,7 +590,7 @@ fn fix_errors() {
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, false) {
+    let png = match PngData::new(output, &Options::default()) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -571,13 +598,81 @@ fn fix_errors() {
         }
     };
 
-    assert_eq!(png.raw.ihdr.color_type, ColorType::Grayscale);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), GRAYSCALE);
     assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
     // Cannot check if pixels are equal because image crate cannot read corrupt (input) PNGs
     remove_file(output).ok();
 }
 
+#[test]
+fn no_color_type_change() {
+    let input = PathBuf::from("tests/files/palette_8_should_be_rgb.png");
+    let (output, mut opts) = get_opts(&input);
+    opts.color_type_reduction = false;
+
+    test_it_converts(
+        input,
+        &output,
+        &opts,
+        INDEXED,
+        BitDepth::Eight,
+        INDEXED,
+        BitDepth::One,
+    );
+}
+
+#[test]
+fn no_grayscale_change() {
+    let input = PathBuf::from("tests/files/rgb_8_should_be_grayscale_8.png");
+    let (output, mut opts) = get_opts(&input);
+    opts.grayscale_reduction = false;
+
+    test_it_converts(
+        input,
+        &output,
+        &opts,
+        RGB,
+        BitDepth::Eight,
+        INDEXED,
+        BitDepth::Eight,
+    );
+}
+
+#[test]
+fn no_bit_depth_change() {
+    let input = PathBuf::from("tests/files/palette_4_should_be_palette_2.png");
+    let (output, mut opts) = get_opts(&input);
+    opts.bit_depth_reduction = false;
+
+    test_it_converts(
+        input,
+        &output,
+        &opts,
+        INDEXED,
+        BitDepth::Four,
+        INDEXED,
+        BitDepth::Four,
+    );
+}
+
+#[test]
+fn scale_16() {
+    let input = PathBuf::from("tests/files/rgb_16_should_be_rgb_16.png");
+    let (output, mut opts) = get_opts(&input);
+    opts.scale_16 = true;
+
+    test_it_converts(
+        input,
+        &output,
+        &opts,
+        RGB,
+        BitDepth::Sixteen,
+        RGB,
+        BitDepth::Eight,
+    );
+}
+
 #[test]
 #[cfg(feature = "zopfli")]
 fn zopfli_mode() {
@@ -591,9 +686,9 @@ fn zopfli_mode() {
         input,
         &output,
         &opts,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
     );
 }
