@@ -1,37 +1,42 @@
 use indexmap::IndexSet;
-use oxipng::{internal_tests::*, Interlacing, RowFilter};
-use oxipng::{InFile, OutFile};
+use oxipng::internal_tests::*;
+use oxipng::*;
 use std::fs::remove_file;
 use std::path::Path;
 use std::path::PathBuf;
 
+const GRAYSCALE: u8 = 0;
+const RGB: u8 = 2;
+const INDEXED: u8 = 3;
+const GRAYSCALE_ALPHA: u8 = 4;
+const RGBA: u8 = 6;
+
 fn get_opts(input: &Path) -> (OutFile, oxipng::Options) {
     let mut options = oxipng::Options {
         force: true,
+        fast_evaluation: false,
+        interlace: None,
         ..Default::default()
     };
     let mut filter = IndexSet::new();
     filter.insert(RowFilter::None);
     options.filter = filter;
 
-    (
-        OutFile::Path(Some(input.with_extension("out.png"))),
-        options,
-    )
+    (OutFile::from_path(input.with_extension("out.png")), options)
 }
 
 fn test_it_converts(
     input: &str,
-    color_type_in: ColorType,
+    color_type_in: u8,
     bit_depth_in: BitDepth,
-    color_type_out: ColorType,
+    color_type_out: u8,
     bit_depth_out: BitDepth,
 ) {
     let input = PathBuf::from(input);
     let (output, opts) = get_opts(&input);
-    let png = PngData::new(&input, opts.fix_errors).unwrap();
+    let png = PngData::new(&input, &opts).unwrap();
 
-    assert_eq!(png.raw.ihdr.color_type, color_type_in);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), color_type_in);
     assert_eq!(png.raw.ihdr.bit_depth, bit_depth_in);
     assert_eq!(png.raw.ihdr.interlaced, Interlacing::Adam7);
 
@@ -42,7 +47,7 @@ fn test_it_converts(
     let output = output.path().unwrap();
     assert!(output.exists());
 
-    let png = match PngData::new(output, opts.fix_errors) {
+    let png = match PngData::new(output, &opts) {
         Ok(x) => x,
         Err(x) => {
             remove_file(output).ok();
@@ -50,7 +55,7 @@ fn test_it_converts(
         }
     };
 
-    assert_eq!(png.raw.ihdr.color_type, color_type_out);
+    assert_eq!(png.raw.ihdr.color_type.png_header_code(), color_type_out);
     assert_eq!(png.raw.ihdr.bit_depth, bit_depth_out);
 
     remove_file(output).ok();
@@ -60,9 +65,9 @@ fn test_it_converts(
 fn interlaced_rgba_16_should_be_rgba_16() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_rgba_16.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
     );
 }
@@ -71,9 +76,9 @@ fn interlaced_rgba_16_should_be_rgba_16() {
 fn interlaced_rgba_16_should_be_rgba_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_rgba_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
     );
 }
@@ -82,9 +87,9 @@ fn interlaced_rgba_16_should_be_rgba_8() {
 fn interlaced_rgba_8_should_be_rgba_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_rgba_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
     );
 }
@@ -93,9 +98,9 @@ fn interlaced_rgba_8_should_be_rgba_8() {
 fn interlaced_rgba_16_should_be_rgb_16() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_rgb_16.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
     );
 }
@@ -104,9 +109,9 @@ fn interlaced_rgba_16_should_be_rgb_16() {
 fn interlaced_rgba_16_should_be_rgb_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_rgb_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
     );
 }
@@ -115,9 +120,9 @@ fn interlaced_rgba_16_should_be_rgb_8() {
 fn interlaced_rgba_8_should_be_rgb_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_rgb_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
     );
 }
@@ -126,9 +131,9 @@ fn interlaced_rgba_8_should_be_rgb_8() {
 fn interlaced_rgba_16_should_be_palette_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_palette_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
     );
 }
@@ -137,9 +142,9 @@ fn interlaced_rgba_16_should_be_palette_8() {
 fn interlaced_rgba_8_should_be_palette_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_palette_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
     );
 }
@@ -148,9 +153,9 @@ fn interlaced_rgba_8_should_be_palette_8() {
 fn interlaced_rgba_16_should_be_palette_4() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_palette_4.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
     );
 }
@@ -159,9 +164,9 @@ fn interlaced_rgba_16_should_be_palette_4() {
 fn interlaced_rgba_8_should_be_palette_4() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_palette_4.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
     );
 }
@@ -170,9 +175,9 @@ fn interlaced_rgba_8_should_be_palette_4() {
 fn interlaced_rgba_16_should_be_palette_2() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_palette_2.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
     );
 }
@@ -181,9 +186,9 @@ fn interlaced_rgba_16_should_be_palette_2() {
 fn interlaced_rgba_8_should_be_palette_2() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_palette_2.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
     );
 }
@@ -192,9 +197,9 @@ fn interlaced_rgba_8_should_be_palette_2() {
 fn interlaced_rgba_16_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_palette_1.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
@@ -203,9 +208,9 @@ fn interlaced_rgba_16_should_be_palette_1() {
 fn interlaced_rgba_8_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_palette_1.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
@@ -214,9 +219,9 @@ fn interlaced_rgba_8_should_be_palette_1() {
 fn interlaced_rgba_16_should_be_grayscale_alpha_16() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_grayscale_alpha_16.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Sixteen,
     );
 }
@@ -225,9 +230,9 @@ fn interlaced_rgba_16_should_be_grayscale_alpha_16() {
 fn interlaced_rgba_16_should_be_grayscale_alpha_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_grayscale_alpha_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Eight,
     );
 }
@@ -236,9 +241,9 @@ fn interlaced_rgba_16_should_be_grayscale_alpha_8() {
 fn interlaced_rgba_8_should_be_grayscale_alpha_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_grayscale_alpha_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Eight,
     );
 }
@@ -247,9 +252,9 @@ fn interlaced_rgba_8_should_be_grayscale_alpha_8() {
 fn interlaced_rgba_16_should_be_grayscale_16() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_grayscale_16.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Sixteen,
     );
 }
@@ -258,9 +263,9 @@ fn interlaced_rgba_16_should_be_grayscale_16() {
 fn interlaced_rgba_16_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_16_should_be_grayscale_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -269,9 +274,9 @@ fn interlaced_rgba_16_should_be_grayscale_8() {
 fn interlaced_rgba_8_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_rgba_8_should_be_grayscale_8.png",
-        ColorType::RGBA,
+        RGBA,
         BitDepth::Eight,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -280,9 +285,9 @@ fn interlaced_rgba_8_should_be_grayscale_8() {
 fn interlaced_rgb_16_should_be_rgb_16() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_rgb_16.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
     );
 }
@@ -291,9 +296,9 @@ fn interlaced_rgb_16_should_be_rgb_16() {
 fn interlaced_rgb_16_should_be_rgb_8() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_rgb_8.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
     );
 }
@@ -302,9 +307,9 @@ fn interlaced_rgb_16_should_be_rgb_8() {
 fn interlaced_rgb_8_should_be_rgb_8() {
     test_it_converts(
         "tests/files/interlaced_rgb_8_should_be_rgb_8.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
     );
 }
@@ -313,9 +318,9 @@ fn interlaced_rgb_8_should_be_rgb_8() {
 fn interlaced_rgb_16_should_be_palette_8() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_palette_8.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
     );
 }
@@ -324,9 +329,9 @@ fn interlaced_rgb_16_should_be_palette_8() {
 fn interlaced_rgb_8_should_be_palette_8() {
     test_it_converts(
         "tests/files/interlaced_rgb_8_should_be_palette_8.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
     );
 }
@@ -335,9 +340,9 @@ fn interlaced_rgb_8_should_be_palette_8() {
 fn interlaced_rgb_16_should_be_palette_4() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_palette_4.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
     );
 }
@@ -346,9 +351,9 @@ fn interlaced_rgb_16_should_be_palette_4() {
 fn interlaced_rgb_8_should_be_palette_4() {
     test_it_converts(
         "tests/files/interlaced_rgb_8_should_be_palette_4.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
     );
 }
@@ -357,9 +362,9 @@ fn interlaced_rgb_8_should_be_palette_4() {
 fn interlaced_rgb_16_should_be_palette_2() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_palette_2.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
     );
 }
@@ -368,9 +373,9 @@ fn interlaced_rgb_16_should_be_palette_2() {
 fn interlaced_rgb_8_should_be_palette_2() {
     test_it_converts(
         "tests/files/interlaced_rgb_8_should_be_palette_2.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
     );
 }
@@ -379,9 +384,9 @@ fn interlaced_rgb_8_should_be_palette_2() {
 fn interlaced_rgb_16_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_palette_1.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
@@ -390,9 +395,9 @@ fn interlaced_rgb_16_should_be_palette_1() {
 fn interlaced_rgb_8_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_rgb_8_should_be_palette_1.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
@@ -401,9 +406,9 @@ fn interlaced_rgb_8_should_be_palette_1() {
 fn interlaced_rgb_16_should_be_grayscale_16() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_grayscale_16.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Sixteen,
     );
 }
@@ -412,9 +417,9 @@ fn interlaced_rgb_16_should_be_grayscale_16() {
 fn interlaced_rgb_16_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_rgb_16_should_be_grayscale_8.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -423,9 +428,9 @@ fn interlaced_rgb_16_should_be_grayscale_8() {
 fn interlaced_rgb_8_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_rgb_8_should_be_grayscale_8.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -434,9 +439,9 @@ fn interlaced_rgb_8_should_be_grayscale_8() {
 fn interlaced_palette_8_should_be_palette_8() {
     test_it_converts(
         "tests/files/interlaced_palette_8_should_be_palette_8.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
     );
 }
@@ -445,9 +450,9 @@ fn interlaced_palette_8_should_be_palette_8() {
 fn interlaced_palette_8_should_be_palette_4() {
     test_it_converts(
         "tests/files/interlaced_palette_8_should_be_palette_4.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
     );
 }
@@ -456,9 +461,9 @@ fn interlaced_palette_8_should_be_palette_4() {
 fn interlaced_palette_4_should_be_palette_4() {
     test_it_converts(
         "tests/files/interlaced_palette_4_should_be_palette_4.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
     );
 }
@@ -467,9 +472,9 @@ fn interlaced_palette_4_should_be_palette_4() {
 fn interlaced_palette_8_should_be_palette_2() {
     test_it_converts(
         "tests/files/interlaced_palette_8_should_be_palette_2.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
     );
 }
@@ -478,9 +483,9 @@ fn interlaced_palette_8_should_be_palette_2() {
 fn interlaced_palette_4_should_be_palette_2() {
     test_it_converts(
         "tests/files/interlaced_palette_4_should_be_palette_2.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
     );
 }
@@ -489,9 +494,9 @@ fn interlaced_palette_4_should_be_palette_2() {
 fn interlaced_palette_2_should_be_palette_2() {
     test_it_converts(
         "tests/files/interlaced_palette_2_should_be_palette_2.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
     );
 }
@@ -500,9 +505,9 @@ fn interlaced_palette_2_should_be_palette_2() {
 fn interlaced_palette_8_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_palette_8_should_be_palette_1.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Eight,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
@@ -511,9 +516,9 @@ fn interlaced_palette_8_should_be_palette_1() {
 fn interlaced_palette_4_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_palette_4_should_be_palette_1.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Four,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
@@ -522,9 +527,9 @@ fn interlaced_palette_4_should_be_palette_1() {
 fn interlaced_palette_2_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_palette_2_should_be_palette_1.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::Two,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
@@ -533,20 +538,31 @@ fn interlaced_palette_2_should_be_palette_1() {
 fn interlaced_palette_1_should_be_palette_1() {
     test_it_converts(
         "tests/files/interlaced_palette_1_should_be_palette_1.png",
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
-        ColorType::Indexed,
+        INDEXED,
         BitDepth::One,
     );
 }
 
+#[test]
+fn interlaced_palette_8_should_be_grayscale_8() {
+    test_it_converts(
+        "tests/files/interlaced_palette_8_should_be_grayscale_8.png",
+        INDEXED,
+        BitDepth::Eight,
+        GRAYSCALE,
+        BitDepth::Eight,
+    );
+}
+
 #[test]
 fn interlaced_grayscale_alpha_16_should_be_grayscale_alpha_16() {
     test_it_converts(
         "tests/files/interlaced_grayscale_alpha_16_should_be_grayscale_alpha_16.png",
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Sixteen,
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Sixteen,
     );
 }
@@ -555,9 +571,9 @@ fn interlaced_grayscale_alpha_16_should_be_grayscale_alpha_16() {
 fn interlaced_grayscale_alpha_16_should_be_grayscale_alpha_8() {
     test_it_converts(
         "tests/files/interlaced_grayscale_alpha_16_should_be_grayscale_alpha_8.png",
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Sixteen,
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Eight,
     );
 }
@@ -566,9 +582,9 @@ fn interlaced_grayscale_alpha_16_should_be_grayscale_alpha_8() {
 fn interlaced_grayscale_alpha_8_should_be_grayscale_alpha_8() {
     test_it_converts(
         "tests/files/interlaced_grayscale_alpha_8_should_be_grayscale_alpha_8.png",
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Eight,
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Eight,
     );
 }
@@ -577,9 +593,9 @@ fn interlaced_grayscale_alpha_8_should_be_grayscale_alpha_8() {
 fn interlaced_grayscale_alpha_16_should_be_grayscale_16() {
     test_it_converts(
         "tests/files/interlaced_grayscale_alpha_16_should_be_grayscale_16.png",
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Sixteen,
     );
 }
@@ -588,9 +604,9 @@ fn interlaced_grayscale_alpha_16_should_be_grayscale_16() {
 fn interlaced_grayscale_alpha_16_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_grayscale_alpha_16_should_be_grayscale_8.png",
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -599,9 +615,9 @@ fn interlaced_grayscale_alpha_16_should_be_grayscale_8() {
 fn interlaced_grayscale_alpha_8_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_grayscale_alpha_8_should_be_grayscale_8.png",
-        ColorType::GrayscaleAlpha,
+        GRAYSCALE_ALPHA,
         BitDepth::Eight,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -610,9 +626,9 @@ fn interlaced_grayscale_alpha_8_should_be_grayscale_8() {
 fn interlaced_grayscale_16_should_be_grayscale_16() {
     test_it_converts(
         "tests/files/interlaced_grayscale_16_should_be_grayscale_16.png",
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Sixteen,
     );
 }
@@ -621,9 +637,9 @@ fn interlaced_grayscale_16_should_be_grayscale_16() {
 fn interlaced_grayscale_16_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_grayscale_16_should_be_grayscale_8.png",
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Sixteen,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -632,9 +648,9 @@ fn interlaced_grayscale_16_should_be_grayscale_8() {
 fn interlaced_grayscale_8_should_be_grayscale_8() {
     test_it_converts(
         "tests/files/interlaced_grayscale_8_should_be_grayscale_8.png",
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
-        ColorType::Grayscale,
+        GRAYSCALE,
         BitDepth::Eight,
     );
 }
@@ -643,10 +659,10 @@ fn interlaced_grayscale_8_should_be_grayscale_8() {
 fn interlaced_small_files() {
     test_it_converts(
         "tests/files/interlaced_small_files.png",
-        ColorType::Indexed,
+        INDEXED,
+        BitDepth::Eight,
+        RGB,
         BitDepth::Eight,
-        ColorType::Indexed,
-        BitDepth::One,
     );
 }
 
@@ -654,9 +670,9 @@ fn interlaced_small_files() {
 fn interlaced_odd_width() {
     test_it_converts(
         "tests/files/interlaced_odd_width.png",
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
-        ColorType::RGB,
+        RGB,
         BitDepth::Eight,
     );
 }
